@@ -14,8 +14,12 @@ from .config import api_protocol, api_url, api_port
 # from .workspacev2 import CompressFormt, ModelFormat, SampleFormat, SampleSource
 # from .workspacev2 import Samples, launch
 
-# logger.remove(0)
-# logger.start(sys.stdout, colorize=True, format="<level>{level}</level> {message}")
+try:
+	logger.remove(0)
+except:
+	pass
+
+logger.start(sys.stdout, colorize=True, format="<level>{level}</level> {message}", level="INFO")
 
 sentry_sdk.init(
     "https://da9cdf5759874504940714a91657de21@o304393.ingest.sentry.io/5901378",
@@ -23,5 +27,5 @@ sentry_sdk.init(
 )
 fpath = os.path.dirname(os.path.abspath(__file__))
 
-__version__= "3.0.0"
+__version__= "4.0.0"
 
