@@ -130,7 +130,7 @@ class ONNCSaaSBuilder(IBuilder):
         r = self._http_req(self.saas_create_project, json=data)
         if r.status_code == requests.codes.ok:
             self._project_id = r.json()["id"]
-            logger.info(f"Project ID: {self._project_id}")
+            logger.debug(f"Project ID: {self._project_id}")
 
         return SaaSResult(r)
 
@@ -139,7 +139,7 @@ class ONNCSaaSBuilder(IBuilder):
         r_list = r.json()
         if len(r_list) > 0:
             self._project_id = r_list[0]["id"]
-            logger.info(f"Project ID: {self._project_id}")
+            logger.debug(f"Project ID: {self._project_id}")
 
         return SaaSResult(r)
 
@@ -153,22 +153,23 @@ class ONNCSaaSBuilder(IBuilder):
     def _saas_create_compilation(self, model_path, dataset_path,
                                 params: Dict = {}):
 
-        logger.info(f'Start to upload model: {model_path}')
+        logger.info(f'Start to upload model')
+        logger.debug(f'Model path: {model_path}')
         model_sr = self.saas_upload_file(model_path)  # type: ignore[arg-type]
         logger.info('The model was uploaded successfully')
 
-        logger.info(f'Start to upload dataset: {dataset_path}')
+        logger.info(f'Start to upload dataset')
+        logger.debug(f'Dataset path: {dataset_path}')
         dataset_sr = self.saas_upload_file(dataset_path)  # type: ignore[arg-type]
         logger.info('The dataset was uploaded successfully')
 
         data = {
-            "model": model_sr.data["files"][0]["url"],
+            "model": 'oasis-fs://' + model_sr.data["files"][0]['id'],
             "modelSize": model_sr.data["files"][0]["size"],
-            "calibration": dataset_sr.data["files"][0]["url"],
+            "calibration": 'oasis-fs://' + dataset_sr.data["files"][0]["id"],
             "calibrationSize": dataset_sr.data["files"][0]["size"],
             "compilerParameters": params
         }
-
         return data
 
     def saas_create_build(self, project_id: str, saas_compilations: List,
@@ -300,7 +301,7 @@ class ONNCSaaSBuilder(IBuilder):
 
         self._build_id = build_sr.data["id"]
 
-        logger.info(f"ONNC-SAAS BuildID: {self._build_id}")
+        logger.debug(f"ONNC-SAAS BuildID: {self._build_id}")
 
         # Wait and poll the result
         t = 0
@@ -332,7 +333,7 @@ class ONNCSaaSBuilder(IBuilder):
                 if state_sr.data["state"] == "success":
                     logger.success(f"Compiled successfully.")
                     file_url = state_sr.data["output"]["deploymentPackage"]
-                    logger.info(file_url)
+                    logger.debug(file_url)
                 else:
                     logger.error(f"Compiled Unsuccessfully: {state_sr.data}")
 
@@ -345,25 +346,26 @@ class ONNCSaaSBuilder(IBuilder):
     def save(self, output: Path) -> Deployment:
         bs = self.saas_get_build_state(self._build_id)
 
+        file_url = bs.data["output"]["deploymentPackage"]
+
+        file_ids = re.findall('oasis-fs://(.*?)$', file_url)
+        if len(file_ids) != 1:
+            logger.error(f"Parse file_id error: {file_url}")
+        else:
+            file_id = file_ids[0]
+
+        tmp_download = get_tmp_path() + '.zip'
+
+        self.saas_download_deployment_package(file_id, tmp_download)
+
+        logger.debug(f"Download file to {tmp_download}")
+
+        with zipfile.ZipFile(tmp_download, 'r') as zip_ref:
+            zip_ref.extractall(output)
+
         if bs.data["state"] == "success":
-            file_url = bs.data["output"]["deploymentPackage"]
-
-            file_ids = re.findall('files/(.*?)$', file_url)
-            if len(file_ids) != 1:
-                logger.error(f"Parse file_id error: {file_url}")
-            else:
-                file_id = file_ids[0]
-
-            tmp_download = get_tmp_path() + '.zip'
-
-            logger.info(tmp_download)
-
-            self.saas_download_deployment_package(file_id, tmp_download)
-
-            with zipfile.ZipFile(tmp_download, 'r') as zip_ref:
-                zip_ref.extractall(output)
-
             deployment = Deployment(output)
+
         else:
             try:
                 deployment = Deployment(None,
