@@ -125,6 +125,6 @@ class ONNCDataset(Dataset):
 
 
 class NDARRAYDataset(Dataset):
-    def __init__(self, raw_dataset: Union[Iterable]):
+    def __init__(self, raw_dataset: Iterable):
         super().__init__(raw_dataset)
         self.format = DatasetFormat.NDARRAY
