@@ -4,6 +4,7 @@ import shutil
 import json
 import os
 
+from onnc.bench.core.model.model import Model
 
 class Deployment:
     """
@@ -59,6 +60,16 @@ class Deployment:
 
         return []
 
+    @property
+    def loadable(self):
+        if os.path.exists(self.base_path):
+            model_src = self.base_path / Path('build')
+            if model_src.exists():
+                for i in os.listdir(model_src):
+                    if i.lower().startswith('model'):
+                        return Model(os.path.join(model_src, i))
+        raise Exception('Unable to get loadable.')
+
     @property
     def compile_logs(self):
         if not self._compile_logs:
