@@ -23,6 +23,7 @@ class ModelFormat(Enum):
     CKPT = 26
 
     TRT_PLAN = 41
+    OPENVINO_IRDIR = 42
 
     GRAPHDEF = 51
 
@@ -35,7 +36,9 @@ TF_MODEL_FORMATS = [ModelFormat.TF_KERAS_MODEL,
                     ModelFormat.KERAS_MODEL,
                     ModelFormat.H5,
                     ModelFormat.SAVED_MODEL,
-                    ModelFormat.PB]
+                    ModelFormat.PB,
+                    ModelFormat.TFLITE,
+                    ModelFormat.CKPT]
 
 
 class ModelDataType(Enum):
