@@ -67,7 +67,7 @@ class ModelPackage:
                 self.model.add_input(tensor)
         else:
             meta_input_names = set([x.name for x in meta.inputs])
-            logger.info(f"meta_input_names: {meta_input_names}")
+            logger.debug(f"meta_input_names: {meta_input_names}")
 
             for idx, i in enumerate(model_inputs):
                 if isinstance(i, list) or isinstance(i, tuple):
