@@ -49,12 +49,6 @@ class Project:
 
     @classmethod
     def get_model_meta(cls, model_package, inputs_as_nchw):
-        if inputs_as_nchw is None:
-            if model_package.model.format in TF_MODEL_FORMATS:
-                inputs_as_nchw = "as_inputs_name"
-            else:
-                inputs_as_nchw = False
-
         model_meta = {
             "inputs": [x.dump() for x in model_package.model.inputs],
             "inputs_as_nchw": inputs_as_nchw,
@@ -81,7 +75,7 @@ class Project:
     def add_model(
             self,
             model: Union[object, str, Path],
-            samples: Union[object, str, Path, Dataset, None],
+            samples: Union[object, str, Path, Dataset, None] = None,
             model_format: ModelFormat = ModelFormat.NON_SPECIFIED,
             sample_format: DatasetFormat = DatasetFormat.NON_SPECIFIED,
             # [name: str, shape:Tuple, dtype:ModelDataType]
@@ -172,7 +166,7 @@ class Project:
         res = self.builder.build(target_id)
 
         if isinstance(self.builder, ONNCSaaSBuilder):
-            logger.info(f"You can visit: https://app.onnc.skymizer.com"
+            logger.info(f"You review compilation report at https://app.onnc.skymizer.com"
                         f"/app/builds/{res['id']}")
 
         return res
